@@ -318,7 +318,7 @@ void FileModel::addFiles(const QVariantMap &files) {
 void FileModel::createFolder(const QModelIndex &parent, const QString &name) {
     emit busy(tr("Creating new folder"));
     m_destinationIndex = parent;
-    emit createFolder(parent.data(ResourcePathRole).toString() + '/' + name);
+    emit createFolder(data(parent, ResourcePathRole).toString() + '/' + name);
 }
 
 void FileModel::onFolderCreated(const QVariantMap &folder) {
@@ -610,6 +610,10 @@ void FileModel::reload(const QModelIndex &parent) {
     getFiles(parent);
 }
 
+void FileModel::clear() {
+    removeFiles(0, rowCount(QModelIndex()), QModelIndex());
+}
+
 void FileModel::onFilesError() {
     setLoading(false);
 }
