@@ -116,7 +116,7 @@ void UbuntuOne::checkTokenSubmission() {
     QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
 
     if (!reply) {
-        emit warning(tr("Network error. Cannot sign in"));
+        emit warning(tr("Network error"));
         return;
     }
 
@@ -124,7 +124,7 @@ void UbuntuOne::checkTokenSubmission() {
     int status = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
 
     if (status == 200) {
-        emit alert(tr("You are signed in to your Ubuntu One account"));
+        emit alert(tr("You have added your Ubuntu One account"));
         token.insert("appName", m_appName);
         token.insert("consumerKey", m_consumerKey);
         token.insert("consumerSecret", m_consumerSecret);
@@ -133,7 +133,7 @@ void UbuntuOne::checkTokenSubmission() {
         emit signedIn(token);
     }
     else {
-        emit warning(tr("Unable to sign in to your Ubuntu One account"));
+        emit warning(tr("Unable to add your Ubuntu One account"));
         setCredentials(token);
     }
 
@@ -205,7 +205,6 @@ void UbuntuOne::setCredentials(const QVariantMap &token) {
     m_consumerSecret = token.value("consumerSecret").toString();
     m_accessToken = token.value("accessToken").toString();
     m_tokenSecret = token.value("tokenSecret").toString();
-    emit userSignedInChanged();
 }
 
 void UbuntuOne::getUserProfile() {
